From 961cb9cc77e2d056011f9b9d8b3baffd834b28b9 Mon Sep 17 00:00:00 2001
From: Justin Clark-Casey (justincc)
Date: Wed, 6 Aug 2014 00:34:09 +0100
Subject: refactor: Rename recent new Client*UpdateTolerance to
Root*UpdateTolerance for better accuracy and consistency with other similar
parameters
---
OpenSim/Region/Framework/Scenes/Scene.cs | 18 +++++++++---------
OpenSim/Region/Framework/Scenes/ScenePresence.cs | 8 ++++----
2 files changed, 13 insertions(+), 13 deletions(-)
(limited to 'OpenSim/Region/Framework')
diff --git a/OpenSim/Region/Framework/Scenes/ScenePresence.cs b/OpenSim/Region/Framework/Scenes/ScenePresence.cs
index c7db306..e792d3f 100644
--- a/OpenSim/Region/Framework/Scenes/ScenePresence.cs
+++ b/OpenSim/Region/Framework/Scenes/ScenePresence.cs
@@ -3200,12 +3200,12 @@ namespace OpenSim.Region.Framework.Scenes
// checks on all updates but the ramifications of this would need careful consideration.
bool updateClients
= IsSatOnObject && (Rotation != m_lastRotation || Velocity != m_lastVelocity || m_pos != m_lastPosition);
-
+
if (!updateClients)
updateClients
- = !Rotation.ApproxEquals(m_lastRotation, Scene.ClientRotationUpdateTolerance)
- || !Velocity.ApproxEquals(m_lastVelocity, Scene.ClientVelocityUpdateTolerance)
- || !m_pos.ApproxEquals(m_lastPosition, Scene.ClientPositionUpdateTolerance);
+ = !Rotation.ApproxEquals(m_lastRotation, Scene.RootRotationUpdateTolerance)
+ || !Velocity.ApproxEquals(m_lastVelocity, Scene.RootVelocityUpdateTolerance)
+ || !m_pos.ApproxEquals(m_lastPosition, Scene.RootPositionUpdateTolerance);
if (updateClients)
{
diff --git a/OpenSim/Region/Framework/Scenes/Scene.cs b/OpenSim/Region/Framework/Scenes/Scene.cs
index cb2c4cd..da99d4f 100644
--- a/OpenSim/Region/Framework/Scenes/Scene.cs
+++ b/OpenSim/Region/Framework/Scenes/Scene.cs
@@ -233,19 +233,19 @@ namespace OpenSim.Region.Framework.Scenes
public bool SendPeriodicAppearanceUpdates { get; set; }
///
/// How much a client has to change position before updates are sent to viewers.
///
- public float ClientPositionUpdateTolerance { get; set; }
+ public float RootPositionUpdateTolerance { get; set; }
///
/// How much a client has to rotate before updates are sent to viewers.
///
- public float ClientRotationUpdateTolerance { get; set; }
+ public float RootRotationUpdateTolerance { get; set; }
///
/// How much a client has to change velocity before updates are sent to viewers.
///
- public float ClientVelocityUpdateTolerance { get; set; }
+ public float RootVelocityUpdateTolerance { get; set; }
///
/// If greater than 1, we only send terse updates to other root agents on every n updates.
@@ -1071,9 +1071,9 @@ namespace OpenSim.Region.Framework.Scenes
PeriodicBackup = true;
UseBackup = true;
- ClientRotationUpdateTolerance = 0.01f;
- ClientVelocityUpdateTolerance = 0.001f;
- ClientPositionUpdateTolerance = 0.05f;
+ RootRotationUpdateTolerance = 0.01f;
+ RootVelocityUpdateTolerance = 0.001f;
+ RootPositionUpdateTolerance = 0.05f;
ChildReprioritizationDistance = 20.0;
m_eventManager = new EventManager();
@@ -233,19 +233,19 @@ namespace OpenSim.Region.Framework.Scenes
public bool SendPeriodicAppearanceUpdates { get; set; }
///
- /// How much a client has to change position before updates are sent to viewers.
+ /// How much a root agent has to change position before updates are sent to viewers.
///
@@ -233,19 +233,19 @@ namespace OpenSim.Region.Framework.Scenes
///
- /// How much a client has to rotate before updates are sent to viewers.
+ /// How much a root agent has to rotate before updates are sent to viewers.
///
@@ -233,19 +233,19 @@ namespace OpenSim.Region.Framework.Scenes
///
- /// How much a client has to change velocity before updates are sent to viewers.
+ /// How much a root agent has to change velocity before updates are sent to viewers.
///
--
cgit v1.1